﻿using System;
using System.Collections.Generic;
using System.Data.SqlServerCe;
using System.IO;
using System.Linq;
using System.Text;
using FluentNHibernate.Cfg;
using FluentNHibernate.Cfg.Db;
using NHibernate;
using NHibernate.Event;
using NHibernate.Tool.hbm2ddl;
using Test;

namespace Test
{
    class Program
    {
        static void Main(string[] args)
        {
            if (File.Exists("LoggingTest.sdf"))
            {
                File.Delete("LoggingTest.sdf");
            }

            //Set up database
            string connectionString = @"Data Source=LoggingTest.sdf;";
            SqlCeEngine en = new SqlCeEngine(connectionString);
            en.CreateDatabase();
            en.Dispose();

            FluentConfiguration config = Fluently.Configure().Database(MsSqlCeConfiguration.Standard
                                                                    .ConnectionString(c => c.Is(connectionString)).ShowSql())
                                                                    .Mappings(x => x.FluentMappings.Add<Class1ClassMap>())
                                                                    .Mappings(x => x.FluentMappings.Add<ChangeLogMap>())
                                                                    .ExposeConfiguration(cfg =>
                                                                    {
                                                                        NHibernateAuditListener listener = new NHibernateAuditListener();
                                                                        cfg.AppendListeners(ListenerType.PostInsert, new[] { listener });
                                                                    });

            new SchemaExport(config.BuildConfiguration()).Create(true, true);
            Console.WriteLine("----------------------------------------------");

            ISessionFactory sf = config.BuildSessionFactory();
            using (ISession session = sf.OpenSession())
            {
                using (ITransaction tr = session.BeginTransaction())
                {
                    session.Save(new Class1()
                        {
                            Id=1,
                            FirstName = "Peter",
                            LastName = "Pan"
                        });
                    tr.Commit();
                }
            }
            Console.WriteLine("----------------------------------------------");
            using (ISession session = sf.OpenSession())
            {
                Console.WriteLine("records in class1 table : " + session.QueryOver<Class1>().List().Count());
                Console.WriteLine("records in changelog table : " + session.QueryOver<ChangeLog>().List().Count());
            }
            Console.WriteLine("----------------------------------------------");
            Console.WriteLine("[Press enter to exit]");
            Console.ReadLine();
        }
    }
}
